==> haskell-ghcide-test-utils-1.9.0.0-244-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghcide-test-utils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide-test-utils
version:              1.9.0.0
visibility:           public
id:                   ghcide-test-utils-1.9.0.0-chz0FEajvDIxtlv2LPPUX
key:                  ghcide-test-utils-1.9.0.0-chz0FEajvDIxtlv2LPPUX
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2022
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             Test utils for ghcide
description:          Test utils for ghcide
category:             Development
abi:                  448f4ffbed4b9e8951c80d5a288ddb4f
exposed:              True
exposed-modules:      Development.IDE.Test Development.IDE.Test.Diagnostic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghcide-test-utils-1.9.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghcide-test-utils-1.9.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghcide-test-utils-1.9.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide-test-utils
hs-libraries:         HSghcide-test-utils-1.9.0.0-chz0FEajvDIxtlv2LPPUX
depends:
    aeson-2.1.2.1-CoFGCad0PesDH4XC5ctCv4 base-4.17.2.1 containers-0.6.7
    data-default-0.7.1.3-3HSSfTTpRalIdOguxliHyd directory-1.3.7.1
    extra-1.7.16-78p7g4t2O5F2wUG9XuP5u filepath-1.4.2.2
    ghcide-2.1.0.0-I7yYw5HJJD61mLVZJ8pGqy
    hls-plugin-api-2.1.0.0-IQqMVgEN6PE8f9aed6cvDb
    lens-5.3.2-KbjCBznXoqo7Dk1sCj4PBt
    lsp-test-0.15.0.1-EmRfzyIhcIZBD89r6lgi8n
    lsp-types-2.0.1.0-ExYjKqfW8zXGiw8krjix35
    tasty-hunit-0.10.2-CBvXc2jt1CTFB9a5803ID3 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-ghcide-test-utils/html/ghcide-test-utils.haddock

haddock-html:         /usr/share/doc/haskell-ghcide-test-utils/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghcide-test-utils-1.9.0.0-245-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghcide-test-utils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide-test-utils
version:              1.9.0.0
visibility:           public
id:                   ghcide-test-utils-1.9.0.0-C94RtyCv5Y5FwnEuNmE6QB
key:                  ghcide-test-utils-1.9.0.0-C94RtyCv5Y5FwnEuNmE6QB
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2022
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             Test utils for ghcide
description:          Test utils for ghcide
category:             Development
abi:                  a3de6745e6af4ad3ed39ae69d5c19caa
exposed:              True
exposed-modules:      Development.IDE.Test Development.IDE.Test.Diagnostic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghcide-test-utils-1.9.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghcide-test-utils-1.9.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghcide-test-utils-1.9.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide-test-utils
hs-libraries:         HSghcide-test-utils-1.9.0.0-C94RtyCv5Y5FwnEuNmE6QB
depends:
    aeson-2.1.2.1-IUt8ms8F4mK1p5ihNOaPfT base-4.17.2.1 containers-0.6.7
    data-default-0.7.1.3-3HSSfTTpRalIdOguxliHyd directory-1.3.7.1
    extra-1.7.16-2947RCqGIqYFOyB1jx0D04 filepath-1.4.2.2
    ghcide-2.1.0.0-DHldTLYQUpI1eP7fVAH6w7
    hls-plugin-api-2.1.0.0-LQgDSMeq7YvFfpKsCKRtrL
    lens-5.3.2-2jnRf5jwH3ZB3yflks8aAl
    lsp-test-0.15.0.1-E0HjwWBegoVBIhzE9QJV5R
    lsp-types-2.0.1.0-LaL8geKqiCtEKVPpcRQmkE
    tasty-hunit-0.10.2-5WwEceQdiurJfxgpFzsYKL text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-ghcide-test-utils/html/ghcide-test-utils.haddock

haddock-html:         /usr/share/doc/haskell-ghcide-test-utils/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
